# -*- coding: utf-8 -*- ----------------------------------------------------===#
#
#  Copyright 2016-2025 Trovares Inc. dba Rocketgraph.  All rights reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#
#===------------------------------------------------------------------------===#

"""
The Python interface to the Rocketgraph xGT graph analytics engine.

Data Loading
============

xGT is a strongly-typed graph system. Loading data is a three step process:

1. Create a namespace or use a pre-created namespace.

  Frame names are represented using a two-level naming scheme. The first part
  represents the namespace in which the frame is stored. Users can create a
  namespace, or, alternatively, system administrators may want to create
  namespaces ahead of time. Creating a namespace can be done with
  :py:meth:`Connection.create_namespace` and a list of existing
  namespaces can be obtained using :py:meth:`Connection.get_namespaces`.

2. Describe the structure and data types of your graph.

  Define the vertex and edge frame structure with
  :py:meth:`Connection.create_vertex_frame` and
  :py:meth:`Connection.create_edge_frame`. Once the type structure is set,
  :py:class:`VertexFrame` and :py:class:`EdgeFrame` objects provide access to
  the server-side structures.

3. Load your edge and vertex data.

  The :py:class:`VertexFrame` and :py:class:`EdgeFrame` objects provide the
  high-performance, parallel :py:meth:`~VertexFrame.load` method to ingest data
  as well as a direct :py:meth:`~VertexFrame.insert` method to add small
  amounts of data piecewise.

Query Processing
================

Queries are expressed as strings written in `OpenCypher <http://docs.rocketgraph.com/learn/tql_intro/index.html>`_.

>>> query ='''
      MATCH  (emp:Employee)-[edge1:ReportsTo]->(boss:Employee)
      RETURN emp.person_id AS employee_id,
             boss.person_id AS boss_id
      INTO   ResultTable
'''

A query runs in the context of a :py:class:`Job`, which can be run, scheduled
and canceled. The :py:meth:`Connection.run_job` method runs the query and
blocks until it finishes successfully, terminates by an error, or is canceled.

Example Script
==============

The following Python script shows some of the functions that can be used to
create a graph, load data into it, run a query and access the results, and
finally remove that graph from the system. ::

  import xgt

  # Connect to xgtd.
  conn = xgt.Connection()

  # Set a default namespace for this session.
  conn.set_default_namespace('career')

  # Define and create the graph in the default namespace.
  employees = conn.create_vertex_frame(
    name='Employees',
    schema=[['person_id', xgt.INT],
            ['name', xgt.TEXT],
            ['postal_code', xgt.INT]],
    key='person_id')

  reports_to = conn.create_edge_frame(
    name='ReportsTo',
    schema=[['employee_id', xgt.INT],
            ['boss_id', xgt.INT],
            ['start_date', xgt.DATE],
            ['end_date', xgt.DATE]],
    source=employees,
    target=employees,
    source_key='employee_id',
    target_key='boss_id')

  # Load data to the graph in xgtd.
  # Use the insert() method for data of a few hundred rows or less;
  # for bigger amounts of data, use the load() method with csv files.
  employees.insert(
    [[111111101, 'Manny', 98103],
     [111111102, 'Trish', 98108],
     [911111501, 'Frank', 98101],
     [911111502, 'Alice', 98102]
    ])
  reports_to.insert(
    [[111111101, 911111501, '2015-01-03', '2017-04-14'],
     [111111102, 911111501, '2016-04-02', '2017-04-14'],
     [911111502, 911111501, '2016-07-07', '2017-04-14'],
     [111111101, 911111502, '2017-04-15', '3000-12-31'],
     [111111102, 911111502, '2017-04-15', '3000-12-31'],
     [911111501, 911111502, '2017-04-15', '3000-12-31']
    ])

  # Query data
  cmd = '''
    MATCH
      (employee:Employees)-[edge1:ReportsTo]->
      (boss:Employees)-[edge2:ReportsTo]->
      (employee)
    WHERE
      edge1.end_date <= edge2.start_date
    RETURN
      employee.person_id AS employee1_id,
      boss.person_id AS employee2_id,
      edge1.start_date AS start1,
      edge1.end_date AS end1,
      edge2.start_date AS start2,
      edge2.end_date AS end2
    INTO
      Results
    '''

  conn.run_job(cmd)
  results = conn.get_frame('Results')

  # Extract the results.
  for frame in [employees, reports_to, results]:
    print('{name}: {n_cols} columns, {n_rows} rows'.format(
      name=frame.name,
      n_cols=len(frame.schema),
      n_rows=frame.num_rows))

  print('\\n--- Results ---')
  for row in results.get_data(0,100):
    print(', '.join([str(c) for c in row]))

  # Drop all objects.
  [conn.drop_frame(f) for f in [reports_to, employees, results]]
"""

__all__ = [
  'BOOLEAN', 'INT', 'UINT', 'FLOAT', 'DATE', 'TIME', 'DATETIME', 'IPADDRESS',
  'TEXT', 'WGSPOINT', 'CARTESIANPOINT'
  'XgtError', 'XgtNotImplemented', 'XgtInternalError',
  'XgtIOError', 'XgtServerMemoryError', 'XgtConnectionError',
  'XgtSyntaxError', 'XgtTypeError', 'XgtValueError', 'XgtNameError',
  'XgtArithmeticError', 'XgtFrameDependencyError', 'XgtTransactionError',
  'XgtSecurityError',
  'Job', 'Connection', 'RowID',
  'VertexFrame', 'EdgeFrame', 'TableFrame']

from .common import (
  BOOLEAN, INT, UINT, FLOAT, DATE, TIME, DATETIME, IPADDRESS, TEXT, LIST, ROWID,
  DURATION, WGSPOINT, CARTESIANPOINT, RowID, XgtError, XgtNotImplemented,
  XgtInternalError, XgtIOError, XgtServerMemoryError, XgtConnectionError,
  XgtSyntaxError, XgtTypeError, XgtValueError, XgtNameError,
  XgtArithmeticError, XgtFrameDependencyError, XgtTransactionError,
  XgtSecurityError
)
from .connection import Connection, BasicAuth, KerberosAuth, PKIAuth, ProxyPKIAuth
from .graph import HeaderMode, VertexFrame, EdgeFrame, TableFrame
from .job import Job

from xgt.ErrorMessages_pb2 import ErrorCodeEnum
from xgt.MetricsService_pb2 import MetricsStatusEnum
from xgt.SchemaMessages_pb2 import JobStatusEnum

from .version import (
  __version__, __version_major__, __version_minor__, __version_patch__
)

import warnings
warnings.filterwarnings(action='ignore', message='numpy.dtype size changed')
warnings.filterwarnings(action='ignore', message='numpy.ufunc size changed')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: AdminService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'AdminService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x41\x64minService.proto\x12\x08xgtproto\x1a\x13\x45rrorMessages.proto\"#\n\x0bStringArray\x12\x14\n\x0cstring_value\x18\x01 \x03(\t\"\x15\n\x04\x44\x61te\x12\r\n\x05value\x18\x01 \x01(\t\"\x15\n\x04Time\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44\x61teTime\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44uration\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\tIPAddress\x12\r\n\x05value\x18\x01 \x01(\t\".\n\x05RowID\x12\x0e\n\x06row_id\x18\x01 \x01(\x04\x12\x15\n\rvalidation_id\x18\x02 \x01(\x04\"\xef\x02\n\tParameter\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12$\n\ndate_value\x18\x05 \x01(\x0b\x32\x0e.xgtproto.DateH\x00\x12$\n\ntime_value\x18\x06 \x01(\x0b\x32\x0e.xgtproto.TimeH\x00\x12,\n\x0e\x64\x61tetime_value\x18\x07 \x01(\x0b\x32\x12.xgtproto.DateTimeH\x00\x12,\n\x0e\x64uration_value\x18\x08 \x01(\x0b\x32\x12.xgtproto.DurationH\x00\x12.\n\x0fipaddress_value\x18\t \x01(\x0b\x32\x13.xgtproto.IPAddressH\x00\x12\'\n\x0crow_id_value\x18\n \x01(\x0b\x32\x0f.xgtproto.RowIDH\x00\x42\x07\n\x05value\"4\n\x0eParameterValue\x12\"\n\x05value\x18\x01 \x03(\x0b\x32\x13.xgtproto.Parameter\"p\n\x0b\x43onfigValue\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x42\x07\n\x05value\"I\n\x17\x43hangeErrorCountRequest\x12.\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x1e.xgtproto.ErrorCountActionEnum\"O\n\x18\x43hangeErrorCountResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"\x1b\n\x19\x46reeUserMemorySizeRequest\"V\n\x1a\x46reeUserMemorySizeResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"\x1a\n\x18MaxUserMemorySizeRequest\"N\n\x19MaxUserMemorySizeResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\" \n\x0fShutdownRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\"2\n\x10ShutdownResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x10\n\x0eVersionRequest\"[\n\x0fVersionResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x17\n\x0f\x65xpiration_date\x18\x03 \x01(\t\">\n\x0fProtocolVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05\"\x81\x01\n\x13\x41uthenticateRequest\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\x12\x0e\n\x06userid\x18\x02 \x01(\t\x12\x10\n\x08pki_cert\x18\x03 \x01(\x0c\x12\x33\n\x10protocol_version\x18\x04 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"\x92\x01\n\x14\x41uthenticateResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x0e\n\x06userid\x18\x03 \x01(\t\x12\x33\n\x10protocol_version\x18\x04 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"|\n\x1bKerberosAuthenticateRequest\x12\x11\n\tkrb_token\x18\x01 \x01(\x0c\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x33\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"\xad\x01\n\x1cKerberosAuthenticateResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x11\n\tkrb_token\x18\x03 \x01(\x0c\x12\x0e\n\x06userid\x18\x04 \x01(\t\x12\x33\n\x10protocol_version\x18\x05 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"\x15\n\x13\x43loseSessionRequest\"6\n\x14\x43loseSessionResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x19\n\x17KeepAliveSessionRequest\":\n\x18KeepAliveSessionResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x1f\n\x10GetConfigRequest\x12\x0b\n\x03key\x18\x01 \x03(\t\"\xb5\x01\n\x11GetConfigResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x39\n\x07\x65ntries\x18\x02 \x03(\x0b\x32(.xgtproto.GetConfigResponse.EntriesEntry\x1a\x45\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"\x93\x01\n\x10SetConfigRequest\x12\x38\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.xgtproto.SetConfigRequest.EntriesEntry\x1a\x45\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"3\n\x11SetConfigResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"7\n\x1aSetDefaultNamespaceRequest\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x01 \x01(\t\"=\n\x1bSetDefaultNamespaceResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x1c\n\x1aGetDefaultNamespaceRequest\"X\n\x1bGetDefaultNamespaceResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x02 \x01(\t\"\x10\n\x0eIsAdminRequest\"C\n\x0fIsAdminResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x10\n\x08is_admin\x18\x02 \x01(\x08*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xe8\n\n\x0c\x41\x64minService\x12[\n\x10\x43hangeErrorCount\x12!.xgtproto.ChangeErrorCountRequest\x1a\".xgtproto.ChangeErrorCountResponse\"\x00\x12\x61\n\x12\x46reeUserMemorySize\x12#.xgtproto.FreeUserMemorySizeRequest\x1a$.xgtproto.FreeUserMemorySizeResponse\"\x00\x12^\n\x11MaxUserMemorySize\x12\".xgtproto.MaxUserMemorySizeRequest\x1a#.xgtproto.MaxUserMemorySizeResponse\"\x00\x12\x43\n\x08Shutdown\x12\x19.xgtproto.ShutdownRequest\x1a\x1a.xgtproto.ShutdownResponse\"\x00\x12@\n\x07Version\x12\x18.xgtproto.VersionRequest\x1a\x19.xgtproto.VersionResponse\"\x00\x12O\n\x0c\x41uthenticate\x12\x1d.xgtproto.AuthenticateRequest\x1a\x1e.xgtproto.AuthenticateResponse\"\x00\x12R\n\x0fPKIAuthenticate\x12\x1d.xgtproto.AuthenticateRequest\x1a\x1e.xgtproto.AuthenticateResponse\"\x00\x12W\n\x14ProxyPKIAuthenticate\x12\x1d.xgtproto.AuthenticateRequest\x1a\x1e.xgtproto.AuthenticateResponse\"\x00\x12g\n\x14KerberosAuthenticate\x12%.xgtproto.KerberosAuthenticateRequest\x1a&.xgtproto.KerberosAuthenticateResponse\"\x00\x12O\n\x0c\x43loseSession\x12\x1d.xgtproto.CloseSessionRequest\x1a\x1e.xgtproto.CloseSessionResponse\"\x00\x12[\n\x10KeepAliveSession\x12!.xgtproto.KeepAliveSessionRequest\x1a\".xgtproto.KeepAliveSessionResponse\"\x00\x12\x46\n\tGetConfig\x12\x1a.xgtproto.GetConfigRequest\x1a\x1b.xgtproto.GetConfigResponse\"\x00\x12\x46\n\tSetConfig\x12\x1a.xgtproto.SetConfigRequest\x1a\x1b.xgtproto.SetConfigResponse\"\x00\x12\x64\n\x13SetDefaultNamespace\x12$.xgtproto.SetDefaultNamespaceRequest\x1a%.xgtproto.SetDefaultNamespaceResponse\"\x00\x12\x64\n\x13GetDefaultNamespace\x12$.xgtproto.GetDefaultNamespaceRequest\x1a%.xgtproto.GetDefaultNamespaceResponse\"\x00\x12@\n\x07IsAdmin\x12\x18.xgtproto.IsAdminRequest\x1a\x19.xgtproto.IsAdminResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AdminService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._loaded_options = None
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._loaded_options = None
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCOUNTACTIONENUM']._serialized_start=2942
  _globals['_ERRORCOUNTACTIONENUM']._serialized_end=3026
  _globals['_STRINGARRAY']._serialized_start=53
  _globals['_STRINGARRAY']._serialized_end=88
  _globals['_DATE']._serialized_start=90
  _globals['_DATE']._serialized_end=111
  _globals['_TIME']._serialized_start=113
  _globals['_TIME']._serialized_end=134
  _globals['_DATETIME']._serialized_start=136
  _globals['_DATETIME']._serialized_end=161
  _globals['_DURATION']._serialized_start=163
  _globals['_DURATION']._serialized_end=188
  _globals['_IPADDRESS']._serialized_start=190
  _globals['_IPADDRESS']._serialized_end=216
  _globals['_ROWID']._serialized_start=218
  _globals['_ROWID']._serialized_end=264
  _globals['_PARAMETER']._serialized_start=267
  _globals['_PARAMETER']._serialized_end=634
  _globals['_PARAMETERVALUE']._serialized_start=636
  _globals['_PARAMETERVALUE']._serialized_end=688
  _globals['_CONFIGVALUE']._serialized_start=690
  _globals['_CONFIGVALUE']._serialized_end=802
  _globals['_CHANGEERRORCOUNTREQUEST']._serialized_start=804
  _globals['_CHANGEERRORCOUNTREQUEST']._serialized_end=877
  _globals['_CHANGEERRORCOUNTRESPONSE']._serialized_start=879
  _globals['_CHANGEERRORCOUNTRESPONSE']._serialized_end=958
  _globals['_FREEUSERMEMORYSIZEREQUEST']._serialized_start=960
  _globals['_FREEUSERMEMORYSIZEREQUEST']._serialized_end=987
  _globals['_FREEUSERMEMORYSIZERESPONSE']._serialized_start=989
  _globals['_FREEUSERMEMORYSIZERESPONSE']._serialized_end=1075
  _globals['_MAXUSERMEMORYSIZEREQUEST']._serialized_start=1077
  _globals['_MAXUSERMEMORYSIZEREQUEST']._serialized_end=1103
  _globals['_MAXUSERMEMORYSIZERESPONSE']._serialized_start=1105
  _globals['_MAXUSERMEMORYSIZERESPONSE']._serialized_end=1183
  _globals['_SHUTDOWNREQUEST']._serialized_start=1185
  _globals['_SHUTDOWNREQUEST']._serialized_end=1217
  _globals['_SHUTDOWNRESPONSE']._serialized_start=1219
  _globals['_SHUTDOWNRESPONSE']._serialized_end=1269
  _globals['_VERSIONREQUEST']._serialized_start=1271
  _globals['_VERSIONREQUEST']._serialized_end=1287
  _globals['_VERSIONRESPONSE']._serialized_start=1289
  _globals['_VERSIONRESPONSE']._serialized_end=1380
  _globals['_PROTOCOLVERSION']._serialized_start=1382
  _globals['_PROTOCOLVERSION']._serialized_end=1444
  _globals['_AUTHENTICATEREQUEST']._serialized_start=1447
  _globals['_AUTHENTICATEREQUEST']._serialized_end=1576
  _globals['_AUTHENTICATERESPONSE']._serialized_start=1579
  _globals['_AUTHENTICATERESPONSE']._serialized_end=1725
  _globals['_KERBEROSAUTHENTICATEREQUEST']._serialized_start=1727
  _globals['_KERBEROSAUTHENTICATEREQUEST']._serialized_end=1851
  _globals['_KERBEROSAUTHENTICATERESPONSE']._serialized_start=1854
  _globals['_KERBEROSAUTHENTICATERESPONSE']._serialized_end=2027
  _globals['_CLOSESESSIONREQUEST']._serialized_start=2029
  _globals['_CLOSESESSIONREQUEST']._serialized_end=2050
  _globals['_CLOSESESSIONRESPONSE']._serialized_start=2052
  _globals['_CLOSESESSIONRESPONSE']._serialized_end=2106
  _globals['_KEEPALIVESESSIONREQUEST']._serialized_start=2108
  _globals['_KEEPALIVESESSIONREQUEST']._serialized_end=2133
  _globals['_KEEPALIVESESSIONRESPONSE']._serialized_start=2135
  _globals['_KEEPALIVESESSIONRESPONSE']._serialized_end=2193
  _globals['_GETCONFIGREQUEST']._serialized_start=2195
  _globals['_GETCONFIGREQUEST']._serialized_end=2226
  _globals['_GETCONFIGRESPONSE']._serialized_start=2229
  _globals['_GETCONFIGRESPONSE']._serialized_end=2410
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._serialized_start=2341
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._serialized_end=2410
  _globals['_SETCONFIGREQUEST']._serialized_start=2413
  _globals['_SETCONFIGREQUEST']._serialized_end=2560
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._serialized_start=2341
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._serialized_end=2410
  _globals['_SETCONFIGRESPONSE']._serialized_start=2562
  _globals['_SETCONFIGRESPONSE']._serialized_end=2613
  _globals['_SETDEFAULTNAMESPACEREQUEST']._serialized_start=2615
  _globals['_SETDEFAULTNAMESPACEREQUEST']._serialized_end=2670
  _globals['_SETDEFAULTNAMESPACERESPONSE']._serialized_start=2672
  _globals['_SETDEFAULTNAMESPACERESPONSE']._serialized_end=2733
  _globals['_GETDEFAULTNAMESPACEREQUEST']._serialized_start=2735
  _globals['_GETDEFAULTNAMESPACEREQUEST']._serialized_end=2763
  _globals['_GETDEFAULTNAMESPACERESPONSE']._serialized_start=2765
  _globals['_GETDEFAULTNAMESPACERESPONSE']._serialized_end=2853
  _globals['_ISADMINREQUEST']._serialized_start=2855
  _globals['_ISADMINREQUEST']._serialized_end=2871
  _globals['_ISADMINRESPONSE']._serialized_start=2873
  _globals['_ISADMINRESPONSE']._serialized_end=2940
  _globals['_ADMINSERVICE']._serialized_start=3029
  _globals['_ADMINSERVICE']._serialized_end=4413
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: MetricsService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'MetricsService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14MetricsService.proto\x12\x08xgtproto\x1a\x13\x45rrorMessages.proto\"\x16\n\x14MetricsStatusRequest\"d\n\x15MetricsStatusResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.xgtproto.MetricsStatusEnum\"\x15\n\x13\x43learMetricsRequest\"6\n\x14\x43learMetricsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error*l\n\x11MetricsStatusEnum\x12\x1a\n\x16UNKNOWN_METRICS_STATUS\x10\x00\x12\x15\n\x11METRICS_COMPLETED\x10\x01\x12\x13\n\x0fMETRICS_RUNNING\x10\x02\x12\x0f\n\x0bMETRICS_OFF\x10\x03\x32\xb8\x01\n\x0eMetricsService\x12U\n\x10GetMetricsStatus\x12\x1e.xgtproto.MetricsStatusRequest\x1a\x1f.xgtproto.MetricsStatusResponse\"\x00\x12O\n\x0c\x43learMetrics\x12\x1d.xgtproto.ClearMetricsRequest\x1a\x1e.xgtproto.ClearMetricsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MetricsService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_METRICSSTATUSENUM']._serialized_start=260
  _globals['_METRICSSTATUSENUM']._serialized_end=368
  _globals['_METRICSSTATUSREQUEST']._serialized_start=55
  _globals['_METRICSSTATUSREQUEST']._serialized_end=77
  _globals['_METRICSSTATUSRESPONSE']._serialized_start=79
  _globals['_METRICSSTATUSRESPONSE']._serialized_end=179
  _globals['_CLEARMETRICSREQUEST']._serialized_start=181
  _globals['_CLEARMETRICSREQUEST']._serialized_end=202
  _globals['_CLEARMETRICSRESPONSE']._serialized_start=204
  _globals['_CLEARMETRICSRESPONSE']._serialized_end=258
  _globals['_METRICSSERVICE']._serialized_start=371
  _globals['_METRICSSERVICE']._serialized_end=555
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import JobService_pb2 as JobService__pb2


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ScheduleJobsCypher = channel.unary_unary(
                '/xgtproto.JobService/ScheduleJobsCypher',
                request_serializer=JobService__pb2.ScheduleJobsCypherRequest.SerializeToString,
                response_deserializer=JobService__pb2.ScheduleJobsCypherResponse.FromString,
                _registered_method=True)
        self.CancelJobs = channel.unary_unary(
                '/xgtproto.JobService/CancelJobs',
                request_serializer=JobService__pb2.CancelJobsRequest.SerializeToString,
                response_deserializer=JobService__pb2.CancelJobsResponse.FromString,
                _registered_method=True)
        self.GetJobs = channel.unary_stream(
                '/xgtproto.JobService/GetJobs',
                request_serializer=JobService__pb2.GetJobsRequest.SerializeToString,
                response_deserializer=JobService__pb2.GetJobsResponse.FromString,
                _registered_method=True)
        self.WaitJobs = channel.unary_unary(
                '/xgtproto.JobService/WaitJobs',
                request_serializer=JobService__pb2.WaitJobsRequest.SerializeToString,
                response_deserializer=JobService__pb2.WaitJobsResponse.FromString,
                _registered_method=True)
        self.CompileQuery = channel.unary_unary(
                '/xgtproto.JobService/CompileQuery',
                request_serializer=JobService__pb2.CompileQueryRequest.SerializeToString,
                response_deserializer=JobService__pb2.CompileQueryResponse.FromString,
                _registered_method=True)


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ScheduleJobsCypher(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobs(self, request, context):
        """Get status of one or more jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompileQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ScheduleJobsCypher': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleJobsCypher,
                    request_deserializer=JobService__pb2.ScheduleJobsCypherRequest.FromString,
                    response_serializer=JobService__pb2.ScheduleJobsCypherResponse.SerializeToString,
            ),
            'CancelJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelJobs,
                    request_deserializer=JobService__pb2.CancelJobsRequest.FromString,
                    response_serializer=JobService__pb2.CancelJobsResponse.SerializeToString,
            ),
            'GetJobs': grpc.unary_stream_rpc_method_handler(
                    servicer.GetJobs,
                    request_deserializer=JobService__pb2.GetJobsRequest.FromString,
                    response_serializer=JobService__pb2.GetJobsResponse.SerializeToString,
            ),
            'WaitJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitJobs,
                    request_deserializer=JobService__pb2.WaitJobsRequest.FromString,
                    response_serializer=JobService__pb2.WaitJobsResponse.SerializeToString,
            ),
            'CompileQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.CompileQuery,
                    request_deserializer=JobService__pb2.CompileQueryRequest.FromString,
                    response_serializer=JobService__pb2.CompileQueryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'xgtproto.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('xgtproto.JobService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ScheduleJobsCypher(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.JobService/ScheduleJobsCypher',
            JobService__pb2.ScheduleJobsCypherRequest.SerializeToString,
            JobService__pb2.ScheduleJobsCypherResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.JobService/CancelJobs',
            JobService__pb2.CancelJobsRequest.SerializeToString,
            JobService__pb2.CancelJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/xgtproto.JobService/GetJobs',
            JobService__pb2.GetJobsRequest.SerializeToString,
            JobService__pb2.GetJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WaitJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.JobService/WaitJobs',
            JobService__pb2.WaitJobsRequest.SerializeToString,
            JobService__pb2.WaitJobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CompileQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.JobService/CompileQuery',
            JobService__pb2.CompileQueryRequest.SerializeToString,
            JobService__pb2.CompileQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: DataService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'DataService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x44\x61taService.proto\x12\x08xgtproto\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\x1a\x1egoogle/protobuf/wrappers.proto\"N\n\x17\x46rameColumnToSourceName\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x18\n\x10\x66ile_column_name\x18\x02 \x01(\t\"L\n\x16\x46rameColumnToSourceIdx\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_column_idx\x18\x02 \x01(\x04\"\xb2\x01\n\rColumnMapping\x12\x46\n\x1b\x66rame_column_to_source_name\x18\x01 \x03(\x0b\x32!.xgtproto.FrameColumnToSourceName\x12\x44\n\x1a\x66rame_column_to_source_idx\x18\x02 \x03(\x0b\x32 .xgtproto.FrameColumnToSourceIdx\x12\x13\n\x0bhas_mapping\x18\x03 \x01(\x08\"\xb1\x01\n\x17UploadRowLevelLabelInfo\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x1c\n\x14label_column_indices\x18\x02 \x03(\x03\x12\x1a\n\x12label_column_names\x18\x03 \x03(\t\x12%\n\x1dimplicit_source_vertex_labels\x18\x04 \x03(\t\x12%\n\x1dimplicit_target_vertex_labels\x18\x05 \x03(\t\"L\n\x19\x44ownloadRowLevelLabelInfo\x12\x14\n\x0c\x65gest_labels\x18\x01 \x01(\x08\x12\x19\n\x11label_header_name\x18\x02 \x01(\t\"\xb5\x04\n\x11UploadDataRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12+\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x15.xgtproto.ContentType\x12-\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x15\n\rauthorization\x18\x05 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x06 \x01(\x08\x12\x35\n\nrow_labels\x18\x07 \x01(\x0b\x32!.xgtproto.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12\x18\n\x10is_python_insert\x18\t \x01(\x08\x12\x11\n\tfile_path\x18\n \x01(\t\x12/\n\x0e\x63olumn_mapping\x18\x0b \x01(\x0b\x32\x17.xgtproto.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\x0c \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\r \x01(\t\x12\x12\n\nrow_filter\x18\x0e \x01(\t\x12\x37\n\x06kwargs\x18\x0f \x03(\x0b\x32\'.xgtproto.UploadDataRequest.KwargsEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"]\n\x12UploadDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\xfd\x03\n\x13\x44ownloadDataRequest\x12\x17\n\x0frepository_name\x18\x01 \x01(\t\x12,\n\x06offset\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x14\n\x0cwith_headers\x18\x04 \x01(\x08\x12+\n\x0c\x63ontent_type\x18\x05 \x01(\x0e\x32\x15.xgtproto.ContentType\x12\x37\n\nrow_labels\x18\x08 \x01(\x0b\x32#.xgtproto.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\t \x01(\x08\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\x12\x39\n\x06kwargs\x18\x0c \x03(\x0b\x32).xgtproto.DownloadDataRequest.KwargsEntry\x12\x12\n\nrow_filter\x18\r \x01(\t\x12\x17\n\x0fwindows_newline\x18\x0e \x01(\x08\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"\x88\x01\n\x14\x44ownloadDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\'\n\njob_status\x18\x03 \x01(\x0b\x32\x13.xgtproto.JobStatus\x12\x16\n\x0enum_row_labels\x18\x04 \x01(\x05\"\xdd\x03\n\x10IngestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x02 \x03(\t\x12-\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x15\n\rauthorization\x18\x04 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x05 \x01(\x08\x12\x36\n\x06kwargs\x18\x06 \x03(\x0b\x32&.xgtproto.IngestUriRequest.KwargsEntry\x12\x35\n\nrow_labels\x18\x07 \x01(\x0b\x32!.xgtproto.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12/\n\x0e\x63olumn_mapping\x18\t \x01(\x0b\x32\x17.xgtproto.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\n \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\x0b \x01(\t\x12\x12\n\nrow_filter\x18\x0c \x01(\t\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"\\\n\x11IngestUriResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\x86\x04\n\x0f\x45gestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x14\n\x0cwith_headers\x18\x03 \x01(\x08\x12\x35\n\x06kwargs\x18\x04 \x03(\x0b\x32%.xgtproto.EgestUriRequest.KwargsEntry\x12\x37\n\nrow_labels\x18\x05 \x01(\x0b\x32#.xgtproto.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\x06 \x01(\x08\x12\x17\n\x0fnumber_of_files\x18\x07 \x01(\x04\x12,\n\x06offset\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\x12\x12\n\nrow_filter\x18\x0c \x01(\t\x12\x15\n\rauthorization\x18\r \x01(\t\x12\x17\n\x0fwindows_newline\x18\x0e \x01(\x08\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"[\n\x10\x45gestUriResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\x80\x01\n\x12InferSchemaRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12-\n\x0bheader_mode\x18\x02 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x11\n\tdelimiter\x18\x03 \x01(\t\x12\x15\n\rauthorization\x18\x04 \x01(\t\"j\n\x13InferSchemaResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12 \n\x06schema\x18\x02 \x01(\x0b\x32\x10.xgtproto.Schema\x12\x11\n\tdelimiter\x18\x03 \x03(\t\"m\n\x07SSLInfo\x12\x0e\n\x06\x64o_ssl\x18\x01 \x01(\x08\x12\x12\n\nchain_cert\x18\x02 \x01(\x0c\x12\x12\n\nclient_key\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63lient_cert\x18\x04 \x01(\x0c\x12\x15\n\rssl_server_cn\x18\x05 \x01(\t\"3\n\x0cUserAuthInfo\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\xa1\x01\n\x1fTransferFrameArrowClientRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x04\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12\x1e\n\x03ssl\x18\x04 \x01(\x0b\x32\x11.xgtproto.SSLInfo\x12)\n\tuser_auth\x18\x05 \x01(\x0b\x32\x16.xgtproto.UserAuthInfo\"k\n TransferFrameArrowClientResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\xe4\x03\n\x19UploadCSVMultiDataRequest\x12\x12\n\nframe_name\x18\x01 \x03(\t\x12+\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x15.xgtproto.ContentType\x12-\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x19\n\x11implicit_vertices\x18\x05 \x01(\x08\x12\x11\n\tdelimiter\x18\x06 \x01(\t\x12\x18\n\x10is_python_insert\x18\x07 \x01(\x08\x12\x11\n\tfile_path\x18\x08 \x01(\t\x12\x17\n\x0fsuppress_errors\x18\t \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\n \x01(\t\x12\x15\n\rstream_length\x18\x0b \x03(\x04\x12P\n\x0f\x63olumn_mappings\x18\x0c \x03(\x0b\x32\x37.xgtproto.UploadCSVMultiDataRequest.ColumnMappingsEntry\x1aN\n\x13\x43olumnMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.xgtproto.ColumnMapping:\x02\x38\x01\"e\n\x1aUploadCSVMultiDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\xdd\x02\n\x1bUploadArrowMultiDataRequest\x12\x12\n\nframe_name\x18\x01 \x03(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x19\n\x11implicit_vertices\x18\x03 \x01(\x08\x12\x11\n\tfile_path\x18\x04 \x01(\t\x12\x17\n\x0fsuppress_errors\x18\x05 \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\x06 \x01(\t\x12R\n\x0f\x63olumn_mappings\x18\x07 \x03(\x0b\x32\x39.xgtproto.UploadArrowMultiDataRequest.ColumnMappingsEntry\x12\x13\n\x0bnum_batches\x18\x08 \x03(\x04\x1aN\n\x13\x43olumnMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.xgtproto.ColumnMapping:\x02\x38\x01\"g\n\x1cUploadArrowMultiDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus*_\n\x0eHeaderModeEnum\x12\x17\n\x13UNKNOWN_HEADER_MODE\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x12\n\x0eIGNORE_HEADERS\x10\x02\x12\n\n\x06NORMAL\x10\x03\x12\n\n\x06STRICT\x10\x04*R\n\x0b\x43ontentType\x12\x13\n\x0fUNKNOWN_CONTENT\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x07\n\x03ZIP\x10\x03\x12\x08\n\x04GZIP\x10\x04\x12\x08\n\x04TZIP\x10\x05\x32\xcf\x05\n\x0b\x44\x61taService\x12K\n\nUploadData\x12\x1b.xgtproto.UploadDataRequest\x1a\x1c.xgtproto.UploadDataResponse\"\x00(\x01\x12Q\n\x0c\x44ownloadData\x12\x1d.xgtproto.DownloadDataRequest\x1a\x1e.xgtproto.DownloadDataResponse\"\x00\x30\x01\x12H\n\tIngestUri\x12\x1a.xgtproto.IngestUriRequest\x1a\x1b.xgtproto.IngestUriResponse\"\x00(\x01\x12\x43\n\x08\x45gestUri\x12\x19.xgtproto.EgestUriRequest\x1a\x1a.xgtproto.EgestUriResponse\"\x00\x12L\n\x0bInferSchema\x12\x1c.xgtproto.InferSchemaRequest\x1a\x1d.xgtproto.InferSchemaResponse\"\x00\x12s\n\x18TransferFrameArrowClient\x12).xgtproto.TransferFrameArrowClientRequest\x1a*.xgtproto.TransferFrameArrowClientResponse\"\x00\x12\x63\n\x12UploadCSVMultiData\x12#.xgtproto.UploadCSVMultiDataRequest\x1a$.xgtproto.UploadCSVMultiDataResponse\"\x00(\x01\x12i\n\x14UploadArrowMultiData\x12%.xgtproto.UploadArrowMultiDataRequest\x1a&.xgtproto.UploadArrowMultiDataResponse\"\x00(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._loaded_options = None
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._loaded_options = None
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_HEADERMODEENUM']._serialized_start=4948
  _globals['_HEADERMODEENUM']._serialized_end=5043
  _globals['_CONTENTTYPE']._serialized_start=5045
  _globals['_CONTENTTYPE']._serialized_end=5127
  _globals['_FRAMECOLUMNTOSOURCENAME']._serialized_start=126
  _globals['_FRAMECOLUMNTOSOURCENAME']._serialized_end=204
  _globals['_FRAMECOLUMNTOSOURCEIDX']._serialized_start=206
  _globals['_FRAMECOLUMNTOSOURCEIDX']._serialized_end=282
  _globals['_COLUMNMAPPING']._serialized_start=285
  _globals['_COLUMNMAPPING']._serialized_end=463
  _globals['_UPLOADROWLEVELLABELINFO']._serialized_start=466
  _globals['_UPLOADROWLEVELLABELINFO']._serialized_end=643
  _globals['_DOWNLOADROWLEVELLABELINFO']._serialized_start=645
  _globals['_DOWNLOADROWLEVELLABELINFO']._serialized_end=721
  _globals['_UPLOADDATAREQUEST']._serialized_start=724
  _globals['_UPLOADDATAREQUEST']._serialized_end=1289
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_UPLOADDATARESPONSE']._serialized_start=1291
  _globals['_UPLOADDATARESPONSE']._serialized_end=1384
  _globals['_DOWNLOADDATAREQUEST']._serialized_start=1387
  _globals['_DOWNLOADDATAREQUEST']._serialized_end=1896
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_DOWNLOADDATARESPONSE']._serialized_start=1899
  _globals['_DOWNLOADDATARESPONSE']._serialized_end=2035
  _globals['_INGESTURIREQUEST']._serialized_start=2038
  _globals['_INGESTURIREQUEST']._serialized_end=2515
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_INGESTURIRESPONSE']._serialized_start=2517
  _globals['_INGESTURIRESPONSE']._serialized_end=2609
  _globals['_EGESTURIREQUEST']._serialized_start=2612
  _globals['_EGESTURIREQUEST']._serialized_end=3130
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_EGESTURIRESPONSE']._serialized_start=3132
  _globals['_EGESTURIRESPONSE']._serialized_end=3223
  _globals['_INFERSCHEMAREQUEST']._serialized_start=3226
  _globals['_INFERSCHEMAREQUEST']._serialized_end=3354
  _globals['_INFERSCHEMARESPONSE']._serialized_start=3356
  _globals['_INFERSCHEMARESPONSE']._serialized_end=3462
  _globals['_SSLINFO']._serialized_start=3464
  _globals['_SSLINFO']._serialized_end=3573
  _globals['_USERAUTHINFO']._serialized_start=3575
  _globals['_USERAUTHINFO']._serialized_end=3626
  _globals['_TRANSFERFRAMEARROWCLIENTREQUEST']._serialized_start=3629
  _globals['_TRANSFERFRAMEARROWCLIENTREQUEST']._serialized_end=3790
  _globals['_TRANSFERFRAMEARROWCLIENTRESPONSE']._serialized_start=3792
  _globals['_TRANSFERFRAMEARROWCLIENTRESPONSE']._serialized_end=3899
  _globals['_UPLOADCSVMULTIDATAREQUEST']._serialized_start=3902
  _globals['_UPLOADCSVMULTIDATAREQUEST']._serialized_end=4386
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_start=4308
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_end=4386
  _globals['_UPLOADCSVMULTIDATARESPONSE']._serialized_start=4388
  _globals['_UPLOADCSVMULTIDATARESPONSE']._serialized_end=4489
  _globals['_UPLOADARROWMULTIDATAREQUEST']._serialized_start=4492
  _globals['_UPLOADARROWMULTIDATAREQUEST']._serialized_end=4841
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_start=4308
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_end=4386
  _globals['_UPLOADARROWMULTIDATARESPONSE']._serialized_start=4843
  _globals['_UPLOADARROWMULTIDATARESPONSE']._serialized_end=4946
  _globals['_DATASERVICE']._serialized_start=5130
  _globals['_DATASERVICE']._serialized_end=5849
# @@protoc_insertion_point(module_scope)
